var servicecom_1_1sun_1_1star_1_1sdbcx_1_1Driver =
[
    [ "com::sun::star::sdbc::Driver", "servicecom_1_1sun_1_1star_1_1sdbcx_1_1Driver.html#abbb18d66714e8f5139514364bc8e3c34", null ],
    [ "XCreateCatalog", "servicecom_1_1sun_1_1star_1_1sdbcx_1_1Driver.html#aa1b77c00b937a21a5224bc2a72bac98b", null ],
    [ "XDataDefinitionSupplier", "servicecom_1_1sun_1_1star_1_1sdbcx_1_1Driver.html#a7196ad876042e73ce2e829c74ecea915", null ],
    [ "XDropCatalog", "servicecom_1_1sun_1_1star_1_1sdbcx_1_1Driver.html#a00f7a490931a4b87dee4325cc4bf8a92", null ]
];